#! /usr/bin/env python

"""Does a "str.replace" on every file name in a directory"""

"""
Copyright 2006 Edward C. Jones

This file is part of mrquery.

mrquery is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

mrquery is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
mrquery; if not, write to the Free Software Foundation, Inc., 51 Franklin
St, Fifth Floor, Boston, MA 02110-1301 USA
"""
import os, sys, re, optparse

usage = "USAGE: renamedir [-h] <string> <string> {<dir>]"
parser = optparse.OptionParser(usage=usage)
parser.add_option('-r', '--re', default=False, action='store_true',
    help='use regular expression as in module re')
options, args = parser.parse_args()

if len(args) not in (2, 3):
    parser.print_help()
    sys.exit('two or three arguments are required')

old = args[0]
new = args[1]
adir = '.'
if len(args) == 3:
    adir = args[2]

if options.re:
    compiled = re.compile(old)
names = os.listdir(adir)
for name in names:
    if name[0] == '.':
        continue
    if options.re:
        newname = compiled.sub(new, name)
    else:
        newname = name.replace(old, new)
    name = os.path.join(adir, name)
    newname = os.path.join(adir, newname)
    if name != newname:
        os.rename(name, newname)
