
"""Weights for Haar transforms.

See Jacobs, Finkelstein and Salesin, "Fast Multiresolution Image Querying".
"""
"""
Copyright 2006 Edward C. Jones

This file is part of mrquery.

mrquery is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

mrquery is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
mrquery; if not, write to the Free Software Foundation, Inc., 51 Franklin
St, Fifth Floor, Boston, MA 02110-1301 USA
"""
import os, numarray
from numarray.numerictypes import *
import constants
from LN import LN, MLLN

class weights:
    """Weights for Haar coefficients.

    Found empirically in mrquery.pdf. They are not invariant under rotation.
    """
    #           Y      I     Q
    scanned = (5.00, 19.21, 34.37,
               0.83, 1.26, 0.36,
               1.01, 0.44, 0.45,
               0.52, 0.53, 0.14,
               0.47, 0.28, 0.18,
               0.3, 0.14, 0.27)

    # scanned = 18*(1.0,)  # For debugging.

    def __init__(self, size):
        self.size = size
        self.makeweights(self.scanned)
        self.makebinarr()
        self.makewtsarr()

    def makeweights(self, weightsdata):
        self.weights = numarray.array(weightsdata, Float64)
        self.weights.shape = (6, constants.LAYERS)

    def makebinarr(self):
        self.binarr = numarray.zeros((self.size, self.size), Int8)
        for i in range(self.size):
            for j in range(self.size):
                self.binarr[i, j] = min(max(i, j), 5)

    def makewtsarr(self):
        # I do not normalize the sum of the weights to be one.
        self.sum0 = 0.0
        self.sum = 0.0
        self.wtsarr = numarray.zeros((constants.LAYERS, self.size, self.size), Float64)
        for i in range(self.size):
            for j in range(self.size):
                for c in range(constants.LAYERS):
                    self.wtsarr[c, i, j] = self.weights[self.binarr[i, j]][c]
                    self.sum += self.wtsarr[c, i, j]
                self.sum0 += self.wtsarr[0, i, j]
        # Normalize weights for b&w images relative to color images. I don't
        # think that it matters, but I do it anyway.
        self.wtsarr0 = self.wtsarr[0, :, :]
#        self.wtsarr0 = self.wtsarr[0, :, :] * self.sum / self.sum0
